@@ -1,4 +1,13 @@
+from __future__ import annotations
+
 import os
+import winreg  # pytype: disable=import-error
+
+from typing import (
+    List,
+    TYPE_CHECKING,
+    Tuple,
+)
 
 from . import (
     encoding,
@@ -7,19 +16,14 @@ from . import (
     win32,
 )
 
-try:
-    import _winreg as winreg  # pytype: disable=import-error
-
-    winreg.CloseKey
-except ImportError:
-    # py2 only
-    import winreg  # pytype: disable=import-error
+if TYPE_CHECKING:
+    from . import ui as uimod
 
 # MS-DOS 'more' is the only pager available by default on Windows.
 fallbackpager = b'more'
 
 
-def systemrcpath():
+def systemrcpath() -> List[bytes]:
     '''return default os-specific hgrc search path'''
     rcpath = []
     filename = win32.executablepath()
@@ -27,7 +31,7 @@ def systemrcpath():
     progrc = os.path.join(os.path.dirname(filename), b'mercurial.ini')
     rcpath.append(progrc)
 
-    def _processdir(progrcd):
+    def _processdir(progrcd: bytes) -> None:
         if os.path.isdir(progrcd):
             for f, kind in sorted(util.listdir(progrcd)):
                 if f.endswith(b'.rc'):
@@ -68,7 +72,7 @@ def systemrcpath():
     return rcpath
 
 
-def userrcpath():
+def userrcpath() -> List[bytes]:
     '''return os-specific hgrc search path to the user dir'''
     home = _legacy_expanduser(b'~')
     path = [os.path.join(home, b'mercurial.ini'), os.path.join(home, b'.hgrc')]
@@ -79,7 +83,7 @@ def userrcpath():
     return path
 
 
-def _legacy_expanduser(path):
+def _legacy_expanduser(path: bytes) -> bytes:
     """Expand ~ and ~user constructs in the pre 3.8 style"""
 
     # Python 3.8+ changed the expansion of '~' from HOME to USERPROFILE.  See
@@ -111,5 +115,5 @@ def _legacy_expanduser(path):
     return userhome + path[i:]
 
 
-def termsize(ui):
+def termsize(ui: uimod.ui) -> Tuple[int, int]:
     return win32.termsize()
